@@ -38,6 +38,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "cachedir.h"
 #include "auth.h"
 
+#include "embedded_auth.h"
+
 weborf_configuration_t weborf_conf = {
     .tar_directory=false,
     .is_inetd=false,
@@ -339,6 +341,13 @@ void configuration_load(int argc, char *argv[]) {
 
     }
 
+#ifdef EMBEDDED_AUTH
+    // Set socket when EMBEDDED_AUTH is set but --auth is not set
+    if (!weborf_conf.authsock) {
+        auth_set_socket("");
+    }
+#endif
+
     if (certificate || key) {
         if (weborf_conf.tar_directory) {
             fprintf(stderr, "Sending directories as tar is not supported while SSL is in use.\n");
