@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2007  Salvo "LtWorf" Tomaselli
+Copyright (C) 2007-2025  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -229,7 +229,7 @@ int main(int argc, char *argv[]) {
 /**
 SIGINT and SIGTERM signal handler
 */
-void quit() {
+void quit(int s) {
 #ifdef SERVERDBG
     syslog(LOG_INFO, "Stopping server...");
 #endif
@@ -281,7 +281,7 @@ void set_new_gid(int gid) {
 Will print the internal status of the queue.
 This function is triggered by SIGUSR1 signal.
 */
-void print_queue_status() {
+void print_queue_status(int s) {
 
     //Lock because the values are read many times and it's needed that they have the same value all the times
 
