@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2007  Salvo "LtWorf" Tomaselli
+Copyright (C) 2007-2025  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,8 +27,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define NOMEM 7
 
 void init_threads(unsigned int count);
-void quit();
-void print_queue_status();
+void quit(int);
+void print_queue_status(int);
 void set_authsocket(char *);
 void chn_thread_count(int val);
 void set_new_uid(int uid);
