@@ -28,4 +28,8 @@ int net_create_server_socket();
 void net_bind_and_listen(int s);
 void net_getpeername(int,char*);
 
+#ifdef IPV6
+char* ip4to6(char*);
+#endif
+
 #endif
